@@ -54,6 +54,7 @@
 /*	int	var_ipc_idle_limit;
 /*	int	var_ipc_ttl_limit;
 /*	char	*var_db_type;
+/*	char	*var_cache_db_type;
 /*	char	*var_hash_queue_names;
 /*	int	var_hash_queue_depth;
 /*	int	var_trigger_timeout;
@@ -168,6 +169,10 @@
 /*	bool	var_relay_before_rcpt_checks;
 /*	bool	var_respectful_logging;
 /*	char	*var_known_tcp_ports;
+/*
+/*	char	*var_nbdb_level;
+/*	char	*var_nbdb_service;
+/*	char	*var_nbdb_cust_map;
 /* DESCRIPTION
 /*	This module (actually the associated include file) defines
 /*	the names and defaults of all mail configuration parameters.
@@ -245,6 +250,7 @@
 #include <verp_sender.h>
 #include <own_inet_addr.h>
 #include <mail_params.h>
+#include <nbdb_util.h>
 #include <compat_level.h>
 #include <config_known_tcp_ports.h>
 
@@ -299,6 +305,7 @@ char   *var_mail_version;
 int     var_ipc_idle_limit;
 int     var_ipc_ttl_limit;
 char   *var_db_type;
+char   *var_cache_db_type;
 char   *var_hash_queue_names;
 int     var_hash_queue_depth;
 int     var_trigger_timeout;
@@ -394,6 +401,10 @@ char   *var_dnssec_probe;
 bool    var_respectful_logging;
 char   *var_known_tcp_ports;
 
+char   *var_nbdb_level;
+char   *var_nbdb_service;
+char   *var_nbdb_cust_map;
+
 const char null_format_string[1] = "";
 
  /*
@@ -401,7 +412,6 @@ const char null_format_string[1] = "";
   */
 int     warn_compat_break_smtp_tlsrpt_skip_reused_hs;
 int     warn_compat_break_smtp_tls_level;
-int     warn_compat_break_lmtp_tls_level;
 int     warn_compat_break_tlsp_clnt_level;
 
  /*
@@ -698,8 +708,6 @@ static void check_legacy_defaults(void)
 	    warn_compat_break_smtp_tlsrpt_skip_reused_hs = 1;
 	if (mail_conf_lookup(VAR_SMTP_TLS_LEVEL) == 0)
 	    warn_compat_break_smtp_tls_level = 1;
-	if (mail_conf_lookup(VAR_LMTP_TLS_LEVEL) == 0)
-	    warn_compat_break_lmtp_tls_level = 1;
 	if (mail_conf_lookup(VAR_TLSP_CLNT_LEVEL) == 0)
 	    warn_compat_break_tlsp_clnt_level = 1;
 #endif
@@ -831,6 +839,7 @@ void    mail_params_init()
 	VAR_ALIAS_DB_MAP, DEF_ALIAS_DB_MAP, &var_alias_db_map, 0, 0,
 	VAR_MAIL_RELEASE, DEF_MAIL_RELEASE, &var_mail_release, 1, 0,
 	VAR_DB_TYPE, DEF_DB_TYPE, &var_db_type, 1, 0,
+	VAR_CACHE_DB_TYPE, DEF_CACHE_DB_TYPE, &var_cache_db_type, 1, 0,
 	VAR_HASH_QUEUE_NAMES, DEF_HASH_QUEUE_NAMES, &var_hash_queue_names, 1, 0,
 	VAR_RCPT_DELIM, DEF_RCPT_DELIM, &var_rcpt_delim, 0, 0,
 	VAR_RELAY_DOMAINS, DEF_RELAY_DOMAINS, &var_relay_domains, 0, 0,
@@ -863,6 +872,9 @@ void    mail_params_init()
 	VAR_SMTPUTF8_AUTOCLASS, DEF_SMTPUTF8_AUTOCLASS, &var_smtputf8_autoclass, 1, 0,
 	VAR_DROP_HDRS, DEF_DROP_HDRS, &var_drop_hdrs, 0, 0,
 	VAR_INFO_LOG_ADDR_FORM, DEF_INFO_LOG_ADDR_FORM, &var_info_log_addr_form, 1, 0,
+	VAR_NBDB_LEVEL, DEF_NBDB_LEVEL, &var_nbdb_level, 1, 0,
+	VAR_NBDB_SERVICE, DEF_NBDB_SERVICE, &var_nbdb_service, 0, 0,
+	VAR_NBDB_CUST_MAP, DEF_NBDB_CUST_MAP, &var_nbdb_cust_map, 0, 0,
 	0,
     };
     static const CONFIG_STR_FN_TABLE function_str_defaults_2[] = {
@@ -1102,4 +1114,9 @@ void    mail_params_init()
 	msg_fatal("file %s/%s: parameters %s and %s: %s",
 		  var_config_dir, MAIN_CONF_FILE,
 		  VAR_VERP_DELIMS, VAR_VERP_FILTER, cp);
+
+    /*
+     * Non-Berkeley-DB migration support.
+     */
+    nbdb_util_init(var_nbdb_level);
 }
