@@ -50,7 +50,8 @@
 #define TLS_LEV_VERIFY		7	/* certificate verified */
 #define TLS_LEV_SECURE		8	/* "secure" verification */
 
-#define TLS_REQUIRED(l)		((l) > TLS_LEV_MAY)
+#define TLS_REQUIRED_BY_SECURITY_LEVEL(l) \
+				((l) > TLS_LEV_MAY)
 #define TLS_MUST_MATCH(l)	((l) > TLS_LEV_ENCRYPT)
 #define TLS_MUST_PKIX(l)	((l) >= TLS_LEV_VERIFY)
 #define TLS_OPPORTUNISTIC(l)	((l) == TLS_LEV_MAY || (l) == TLS_LEV_DANE)
@@ -132,6 +133,14 @@ extern const char *str_tls_level(int);
     SSL_group_to_name((ssl), SSL_get_negotiated_group(ssl))
 #else
 #define TLS_GROUP_NAME(ssl) ((const char *)0)
+#endif
+
+#if OPENSSL_VERSION_PREREQ(4,0)
+#define TLS_ADD1_HOST   SSL_add1_dnsname
+#define TLS_SET1_HOST   SSL_set1_dnsname
+#else
+#define TLS_ADD1_HOST   SSL_add1_host
+#define TLS_SET1_HOST   SSL_set1_host
 #endif
 
  /*
@@ -267,7 +276,7 @@ typedef struct {
     VSTREAM *stream;			/* Blocking-mode SMTP session */
     /* DANE TLSA trust input and verification state */
     const TLS_DANE *dane;		/* DANE TLSA digests */
-    X509   *errorcert;			/* Error certificate closest to leaf */
+    const X509 *errorcert;		/* Error certificate closest to leaf */
     int     errordepth;			/* Chain depth of error cert */
     int     errorcode;			/* First error at error depth */
     int     must_fail;			/* Failed to load trust settings */
