@@ -319,6 +319,7 @@ static void uncache_session(SSL_CTX *ctx, TLS_SESS_STATE *TLScontext)
 static void verify_x509(TLS_SESS_STATE *TLScontext, X509 *peercert,
 			        const TLS_CLIENT_START_PROPS *props)
 {
+    int     x509_err = SSL_get_verify_result(TLScontext->con);
 
     /*
      * On exit both peer_CN and issuer_CN should be set.
@@ -330,7 +331,7 @@ static void verify_x509(TLS_SESS_STATE *TLScontext, X509 *peercert,
      * Is the certificate trust chain trusted and matched?  Any required name
      * checks are now performed internally in OpenSSL.
      */
-    if (SSL_get_verify_result(TLScontext->con) == X509_V_OK) {
+    if (x509_err == X509_V_OK) {
 	TLScontext->peer_status |= TLS_CERT_FLAG_TRUSTED;
 	if (TLScontext->must_fail) {
 	    msg_panic("%s: cert valid despite trust init failure",
@@ -363,11 +364,11 @@ static void verify_x509(TLS_SESS_STATE *TLScontext, X509 *peercert,
 	    }
 	}
     } else if (TLS_MUST_MATCH(TLScontext->level) &&
-	       TLScontext->errordepth == 0 &&
-	       TLScontext->errorcode == X509_V_ERR_HOSTNAME_MISMATCH) {
+	       x509_err == X509_V_ERR_HOSTNAME_MISMATCH) {
+
 	/*
-	 * If the only error is a hostname mismatch, the certificate must have
-	 * been trusted.
+	 * If the only error is a hostname mismatch, the certificate must
+	 * have been trusted.
 	 */
 	TLScontext->peer_status |= TLS_CERT_FLAG_TRUSTED;
     }
@@ -516,7 +517,7 @@ static void add_namechecks(TLS_SESS_STATE *TLScontext,
 #endif
 
 	if (!match_subdomain) {
-	    if (SSL_add1_host(ssl, name))
+	    if (TLS_ADD1_HOST(ssl, name))
 		++namechecks_count;
 	    else
 		msg_warn("%s: error loading match name: \"%s\"",
@@ -524,7 +525,7 @@ static void add_namechecks(TLS_SESS_STATE *TLScontext,
 	} else {
 	    char   *dot_name = concatenate(".", name, (char *) 0);
 
-	    if (SSL_add1_host(ssl, dot_name))
+	    if (TLS_ADD1_HOST(ssl, dot_name))
 		++namechecks_count;
 	    else
 		msg_warn("%s: error loading match name: \"%s\"",
