@@ -59,6 +59,7 @@ typedef struct VSTREAM {
     VSTREAM_JMP_BUF *jbuf;		/* exception handling */
     struct timeval iotime;		/* time of last fill/flush */
     struct timeval time_limit;		/* read/write time limit */
+    int     min_data_rate;		/* min data rate for time limit */
     struct VSTRING *vstring;		/* memory-backed stream */
 } VSTREAM;
 
@@ -157,6 +158,7 @@ extern void vstream_control(VSTREAM *, int,...);
 #define VSTREAM_CTL_START_DEADLINE 14
 #define VSTREAM_CTL_STOP_DEADLINE 15
 #define VSTREAM_CTL_OWN_VSTRING	16
+#define VSTREAM_CTL_MIN_DATA_RATE 17
 
 /* Safer API: type-checked arguments, external use. */
 #define CA_VSTREAM_CTL_END		VSTREAM_CTL_END
@@ -178,6 +180,7 @@ extern void vstream_control(VSTREAM *, int,...);
 #define CA_VSTREAM_CTL_START_DEADLINE	VSTREAM_CTL_START_DEADLINE
 #define CA_VSTREAM_CTL_STOP_DEADLINE	VSTREAM_CTL_STOP_DEADLINE
 #define CA_VSTREAM_CTL_OWN_VSTRING	VSTREAM_CTL_OWN_VSTRING
+#define CA_VSTREAM_CTL_MIN_DATA_RATE(v)	VSTREAM_CTL_MIN_DATA_RATE, CHECK_VAL(VSTREAM_CTL, int, (v))
 
 CHECK_VAL_HELPER_DCL(VSTREAM_CTL, ssize_t);
 CHECK_VAL_HELPER_DCL(VSTREAM_CTL, int);
@@ -272,6 +275,11 @@ extern int vstream_tweak_tcp(VSTREAM *);
 	vstream_memreopen((VSTREAM *) 0, (string), (flags))
 VSTREAM *vstream_memreopen(VSTREAM *, struct VSTRING *, int);
 
+ /*
+  * Debug logging lockout.
+  */
+extern void vstream_no_debug(VSTREAM *);
+
 /* LICENSE
 /* .ad
 /* .fi
